@@ -1,7 +1,7 @@
 use 5.014;
 use warnings;
 
-our ($ROUND);
+our ($ROUND, $PREC);
 
 Class::Multimethods::multimethod __acos__ => qw(Math::MPFR) => sub {
     my ($x) = @_;
@@ -9,19 +9,20 @@ Class::Multimethods::multimethod __acos__ => qw(Math::MPFR) => sub {
     # Return a complex number for x < -1 or x > 1
     if (   Math::MPFR::Rmpfr_cmp_ui($x, 1) > 0
         or Math::MPFR::Rmpfr_cmp_si($x, -1) < 0) {
-        $x = _mpfr2mpc($x);
-        Math::MPC::Rmpc_acos($x, $x, $ROUND);
-        return $x;
+        my $r = _mpfr2mpc($x);
+        Math::MPC::Rmpc_acos($r, $r, $ROUND);
+        return $r;
     }
 
-    Math::MPFR::Rmpfr_acos($x, $x, $ROUND);
-    $x;
+    my $r = Math::MPFR::Rmpfr_init2($PREC);
+    Math::MPFR::Rmpfr_acos($r, $x, $ROUND);
+    $r;
 };
 
 Class::Multimethods::multimethod __acos__ => qw(Math::MPC) => sub {
-    my ($x) = @_;
-    Math::MPC::Rmpc_acos($x, $x, $ROUND);
-    $x;
+    my $r = Math::MPC::Rmpc_init2($PREC);
+    Math::MPC::Rmpc_acos($r, $_[0], $ROUND);
+    $r;
 };
 
 1;
