@@ -7,16 +7,17 @@ our ($ROUND, $PREC);
 
 Class::Multimethods::multimethod __hypot__ => qw(Math::MPFR Math::MPFR) => sub {
     my ($x, $y) = @_;
-    Math::MPFR::Rmpfr_hypot($x, $x, $y, $ROUND);
-    $x;
+    my $r = Math::MPFR::Rmpfr_init2($PREC);
+    Math::MPFR::Rmpfr_hypot($r, $x, $y, $ROUND);
+    $r;
 };
 
 Class::Multimethods::multimethod __hypot__ => qw(Math::MPFR Math::MPC) => sub {
     my ($x, $y) = @_;
     my $r = Math::MPFR::Rmpfr_init2($PREC);
     Math::MPC::Rmpc_abs($r, $y, $ROUND);
-    Math::MPFR::Rmpfr_hypot($x, $x, $r, $ROUND);
-    $x;
+    Math::MPFR::Rmpfr_hypot($r, $r, $x, $ROUND);
+    $r;
 };
 
 Class::Multimethods::multimethod __hypot__ => qw(Math::MPC Math::MPFR) => sub {
@@ -31,9 +32,9 @@ Class::Multimethods::multimethod __hypot__ => qw(Math::MPC Math::MPC) => sub {
     my ($x, $y) = @_;
     my $r = Math::MPFR::Rmpfr_init2($PREC);
     Math::MPC::Rmpc_abs($r, $x, $ROUND);
-    my $f = Math::MPFR::Rmpfr_init2($PREC);
-    Math::MPC::Rmpc_abs($f, $y, $ROUND);
-    Math::MPFR::Rmpfr_hypot($r, $r, $f, $ROUND);
+    my $t = Math::MPFR::Rmpfr_init2($PREC);
+    Math::MPC::Rmpc_abs($t, $y, $ROUND);
+    Math::MPFR::Rmpfr_hypot($r, $r, $t, $ROUND);
     $r;
 };
 
